@@ -29,3 +29,6 @@ test_tidy(step_adasyn)
 test_over_ratio(step_adasyn)
 test_multiclass(step_adasyn)
 test_multi_majority(step_adasyn)
+test_factor_level_memory(step_adasyn)
+test_result_ordering(step_adasyn)
+test_id_variables_are_ignores(step_adasyn)
