@@ -48,3 +48,5 @@ test_na_response(step_rose)
 test_seed(step_rose)
 test_tidy(step_rose)
 test_2_class_only(step_rose)
+test_factor_level_memory(step_rose)
+test_id_variables_are_ignores(step_rose)
