@@ -45,3 +45,6 @@ test_tidy(step_smote)
 test_over_ratio(step_smote)
 test_multiclass(step_smote)
 test_multi_majority(step_smote)
+test_factor_level_memory(step_smote)
+test_result_ordering(step_smote)
+test_id_variables_are_ignores(step_smote)
